==> piwigo-2.1.3.zip: piwigo/plugins/LocalFilesEditor/language/hr_HR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+


$lang['locfiledit_onglet_localconf'] = 'Lokalno podešavanje';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Predlošci';
$lang['locfiledit_onglet_lang'] = 'Jezici';
$lang['locfiledit_onglet_plug'] = 'Osobni plugin';
$lang['locfiledit_cant_save'] = 'Trenutna datoteka ne može se zapisati. Provjerite može li se zapisivati u mapu "include/" (chmod).';
$lang['locfiledit_newfile'] = 'Datoteka ne postoji i bit ce kreirana pomocu LocalFiles Editor-a';
$lang['locfiledit_save_config'] = 'Datoteka uspješno zapisana.';
$lang['locfiledit_show_default'] = 'Prikaži referentnu datoteku: ';
$lang['locfiledit_save_bak'] = 'Sigurnosna kopija ce biti kreirana kod spremanja.';
$lang['locfiledit_saved_bak'] = 'Sigurnosna kopija kreirana (%s)';
$lang['locfiledit_save_file'] = 'Spremi datoteku';
$lang['locfiledit_choose_file'] = 'Odaberi datoteku za uredivanje';
$lang['locfiledit_edit'] = 'Uredi';
$lang['locfiledit_restore'] = 'Vrati sigurnosnu kopiju datoteke';
$lang['locfiledit_restore_confirm'] = 'Molimo potvrdite.
Vracanje kopije nece biti prihvaceno do sljedeceg spremanja.';
$lang['locfiledit_bak_loaded1'] = 'Sigurnosna kopija datoteke ucitana.';
$lang['locfiledit_bak_loaded2'] = 'Morate snimiti datoteku kako bi je vratili u prijašnje stanje.';
$lang['locfiledit_syntax_error'] = 'Greška u sintaksi! Datoteka ne može biti spremljena.';
$lang['locfiledit_enable_editarea'] = 'Aktiviraj prostor za uredivanje';
$lang['locfiledit_disable_editarea'] = 'Deaktiviraj prostor za uredivanje';
$lang['locfiledit_new_tpl'] = 'Kreiraj novu datoteku';
$lang['locfiledit_new_filename'] = 'Naziv datoteke';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Prazna stranica';
$lang['locfiledit_parent_directory'] = 'Prethodna mapa';
$lang['locfiledit_filename_error'] = 'Zabranjeni znakovi u nazivu datoteke.';
$lang['locfiledit_file_already_exists'] = 'Datoteka vec postoji.';
$lang['locfiledit_model_error'] = 'Morate odabrati model.';
$lang['locfiledit_empty_filename'] = 'Morate popuniti naziv datoteke.';
$lang['locfiledit_webmaster_only'] = 'Samo webmasteri mogu kreirati ili mijenjati lokalne datoteke.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/hr_HR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+


$lang['locfiledit_onglet_localconf'] = 'Lokalno podešavanje';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Predlošci';
$lang['locfiledit_onglet_lang'] = 'Jezici';
$lang['locfiledit_onglet_plug'] = 'Osobni plugin';
$lang['locfiledit_cant_save'] = 'Trenutna datoteka ne može se zapisati. Provjerite može li se zapisivati u mapu "local/" (chmod).';
$lang['locfiledit_newfile'] = 'Datoteka ne postoji i bit ce kreirana pomocu LocalFiles Editor-a';
$lang['locfiledit_save_config'] = 'Datoteka uspješno zapisana.';
$lang['locfiledit_show_default'] = 'Prikaži referentnu datoteku: ';
$lang['locfiledit_save_bak'] = 'Sigurnosna kopija ce biti kreirana kod spremanja.';
$lang['locfiledit_saved_bak'] = 'Sigurnosna kopija kreirana (%s)';
$lang['locfiledit_save_file'] = 'Spremi datoteku';
$lang['locfiledit_choose_file'] = 'Odaberi datoteku za uredivanje';
$lang['locfiledit_edit'] = 'Uredi';
$lang['locfiledit_restore'] = 'Vrati sigurnosnu kopiju datoteke';
$lang['locfiledit_restore_confirm'] = 'Molimo potvrdite.
Vracanje kopije nece biti prihvaceno do sljedeceg spremanja.';
$lang['locfiledit_bak_loaded1'] = 'Sigurnosna kopija datoteke ucitana.';
$lang['locfiledit_bak_loaded2'] = 'Morate snimiti datoteku kako bi je vratili u prijašnje stanje.';
$lang['locfiledit_syntax_error'] = 'Greška u sintaksi! Datoteka ne može biti spremljena.';
$lang['locfiledit_enable_editarea'] = 'Aktiviraj prostor za uredivanje';
$lang['locfiledit_disable_editarea'] = 'Deaktiviraj prostor za uredivanje';
$lang['locfiledit_new_tpl'] = 'Kreiraj novu datoteku';
$lang['locfiledit_new_filename'] = 'Naziv datoteke';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Prazna stranica';
$lang['locfiledit_parent_directory'] = 'Prethodna mapa';
$lang['locfiledit_filename_error'] = 'Zabranjeni znakovi u nazivu datoteke.';
$lang['locfiledit_file_already_exists'] = 'Datoteka vec postoji.';
$lang['locfiledit_model_error'] = 'Morate odabrati model.';
$lang['locfiledit_empty_filename'] = 'Morate popuniti naziv datoteke.';
$lang['locfiledit_webmaster_only'] = 'Samo webmasteri mogu kreirati ili mijenjati lokalne datoteke.';

?>
